--
-- Mod: FS22_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersFieldPrices by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.0.0.7
-- 26-11-2021
-- Version 1.0.0.8
-- 		Included harvest yield, value, and value/ha in lAlt-ry printout
-- Version 1.0.1.0
--		Nothing new
-- Version 1.0.1.1
--		Nothing new
-- Version 1.0.1.2
--		Introducing annual lease termination 
--      RN.fieldLeaseTerminationMonth = 1;
--      With this setting, farmland leases terminate in January.
--      The value of leasable land is set to zero in all of January.
--      During all of January, buying a leasable land will be canceled within 10 min.
--		The land lease cost is proportional to the fraction of lease period left.
--		If you lease the land in August, the lease price is 5/12 of the annual lease.
--		If you renew the lease in February, the lease cost is 11/12 of the annual cost.
--		If you terminate the lease in October you will be refunded 3/12 of the annual lease.
--		This should not have any effect on crop growth. 
--		If you renew the lease in Februrary you reclaim your winter crop.
--      You can lease a farmland just before harvesting and run away with the profit. 
--		Your game, your ethics :-).
-- Version 1.0.1.3
-- 		Nothing new
--[[

To identify fields you want to define as rentable,
run the script and press lAlt-rf in the game.
A list of farmland information is printed to the log file.
Find the farmland, that the field belongs to,
and enter the farmland index into the list in the
associated xml file. If there are multiple fields
in one farmland, all fields belonging to this farmland
will be rentable. This is because only farmland is traded,
not individual fields.

To printout information on field you own, press lAlt-ry.
This will provide a list of field numbers, area, seed usage,
yield, value of crop, and value of crop per hectare.

If you grow the crop for selling, the value of crop per hectare
should guide you to choose the most rewarding crop.

--]]


RealNumbersFieldPrices = {};
function myPrint(text, number, textWidth, unit)
	print(string.format("%s =  %8.0f %s", text..string.rep(" ",textWidth-string.len(text)),number,"    "..unit));
end;
function myPrintFloat(text, number, textWidth, unit)
	print(string.format("%s =  %12.4f %s", text..string.rep(" ",textWidth-string.len(text)),number, unit));
end;
function myPrintString(text, text2, textWidth, unit)
	print(string.format("%s =  %s %s", text..string.rep(" ",textWidth-string.len(text)),text2, unit));
end;
function myPrintMyFields(FieldID, FieldArea, SeedUsage, Yield, Value, ValuePerHa, WindrowYield, FruitName, textWidth)
	print(string.format("%6d %12.2f %12.1f %12.0f %12.0f %12.0f %12.0f %s ",
					FieldID, FieldArea, SeedUsage, Yield, Value, ValuePerHa, WindrowYield, FruitName..string.rep(" ",textWidth-string.len(FruitName))));
end;

function print_r (t, indent, done)
  done = done or {}
  indent = indent or ''
  local nextIndent -- Storage for next indentation value
  for key, value in pairs (t) do
    if type (value) == "table" and not done [value] then
      nextIndent = nextIndent or
          (indent .. string.rep(' ',string.len(tostring (key))+2))
          -- Shortcut conditional allocation
      done [value] = true
      print (indent .. "[" .. tostring (key) .. "] => Table {");
      print  (nextIndent .. "{");
      print_r (value, nextIndent .. string.rep(' ',2), done)
      print  (nextIndent .. "}");
    else
      print  (indent .. "[" .. tostring (key) .. "] => " .. tostring (value).."")
    end
  end
end

function RealNumbersFieldPrices:loadMap(name)
	local textWidth 	= 30;
	local useMyXMLfile	= false;
	local farmland = {};
	local farmlandArea = 0;
	local farmlandId = 0;
	local isOwned = false;
	local fieldId = 0;
	local fieldArea = 0;
	local fruitTypeIndex = 0;
	local fruitType = {};
	local currency = "€";	-- or  "$" or "£"
	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end;

	RN.notRunYetRealNumbersFieldPrices = true;
	RN.upStartRealNumbersFieldPrices = true;

	RN.farmlandOwnerType 	= {};
	RN.fieldPrices 			= {};
	RN.farmlandForLease 	= {};
	RN.fieldLeaseTerminationMonth = 1;
	RN.cropValueScale		= 0.50;			-- Fraction of crop value paid to owner when buying field with crops.


	print("\n --- RealNumbersFieldPrices.lua started : press lAlt-rf or lAlt-ry --- \n");

	local modSettingsDir = getUserProfileAppPath() .. "modSettings";
	if modSettingsDir == nil then
		print(" ");
		print("modSettingsDir undefined");
		print(" ");
	end;
	
	local savegameIndex = 0;
	if g_currentMission.missionInfo.savegameIndex ~= nil then
		savegameIndex = g_currentMission.missionInfo.savegameIndex;
	end;
	local RNmodSettingsDir = modSettingsDir .. "/RealLifeNumbers/savegame" .. savegameIndex;

	local myFarmLandXML = RNmodSettingsDir.."/my_farmLand.xml";
	if fileExists(myFarmLandXML) then
		print("\n --- my XML file is used --- \n")
		useMyXMLfile = true;
	else
		print("xml file does not exist for this savegame");
		useMyXMLfile = false;
	end;

	if g_currentMission.missionInfo.mapTitle ~= nil then
		local mapName = g_currentMission.missionInfo.mapTitle;
		print("\n --- "..mapName.. " --- \n");
	end;

	if fileExists(myFarmLandXML) then

		local xmlFile = loadXMLFile("fruitTypes", myFarmLandXML);
		print("Loading file:");
		print(myFarmLandXML);
		print(" ");
		local xmlKey = string.format("farmlands.prices");

		RN.fieldPrices.pricePerHa 			= math.floor(tonumber(getXMLString(xmlFile, xmlKey .. "#pricePerHa")));
		RN.fieldPrices.rentPriceScale 		= getXMLFloat(xmlFile, xmlKey .. "#rentPriceScale");
		RN.fieldPrices.permitFieldRent		= getXMLBool(xmlFile, xmlKey .. "#permitFieldRent");

		myPrint("Price Per hectar",RN.fieldPrices.pricePerHa,textWidth,currency);
		myPrintFloat("Price scale for renting",RN.fieldPrices.rentPriceScale,textWidth," ");
		myPrintString("Field rent allowed",tostring(RN.fieldPrices.permitFieldRent),textWidth," ");

		local m = 0;
		while true do
			local xmlKey2 = string.format("farmlands.farmlandsForRent.farmland(%d)", m);
			if not hasXMLProperty(xmlFile, xmlKey2) then
				print(" End of file or does not have xml property");
				break;
			end;
			RN.farmlandForLease[m+1] 		= math.floor(tonumber(getXMLString(xmlFile, xmlKey2 .. "#farmlandId")));
			print("Rentable farmland id : "..RN.farmlandForLease[m+1]);
			m = m + 1;
		end;
	else

		RN.fieldPrices.pricePerHa 		= 25000;	-- default RLN value = 25000 eu/ha farmland - not per field ha. Vanilla game = 60000 eu/ha
		RN.fieldPrices.rentPriceScale 	= 0.03;		-- default RLN value = 0.03 (3% of farmland price)
		RN.fieldPrices.permitFieldRent = true;		-- default RLN vaulue = true. Change to false if not allowed
		RN.farmlandForLease = {2, 5, 9, 13, 15, 18, 21, 25, 29, 33, 36, 38, 40, 45, 48, 52, 55, 57}; 	-- farmland indices - not field indices

	end;

	print("\n --- RealNumbersFieldPrices.lua updates every 10 min --- \n");
end;


function RealNumbersFieldPrices:keyEvent(unicode, sym, modifier, isDown)
	local farmland 			= {};
	local farmlandArea 		= 0;
	local farmlandId		= 0;
	local isOwned 			= false;
	local fieldId 			= 0;
	local fieldArea 		= 0;
	local fruitTypeIndex 	= 0;
	local fruitType 		= {};
	local seedUsage			= 0;
	local pricePerLiter 	= 0;
	local maxYield 			= 0;
	local windrowYield		= 0;
	local value				= 0;
	local valuePerHa		= 0;
	local textWidth			= 20;


	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_f) then


			print("\n --- RealNumbersFieldPrices.lua started : press lAlt-rf --- \n");

			local mapName = g_currentMission.missionInfo.mapTitle;
			print("\n --- "..mapName.. " --- \n");

			if g_fieldManager.farmlandIdFieldMapping ~= nil then
				for i, land in pairs(g_fieldManager.farmlandIdFieldMapping) do

					for k, field in pairs(land) do
						farmland = field.farmland;
						farmlandArea = farmland.areaInHa;
						farmlandId = farmland.id;
						isOwned = farmland.isOwned;
						fieldId = field.fieldId;
						fieldArea = field.fieldArea;
						fruitTypeIndex = field.fruitType;
						fruitType = g_fruitTypeManager:getFruitTypeByIndex(fruitTypeIndex);
						if fruitType ~= nil then
							fruitName = fruitType.name;
						else
							fruitName = "Undefined";
						end;
--[[
						farmland.price =  RN.fieldPrices.pricePerHa * farmlandArea;
						RN.farmlandOwnerType[i] = "For sale";
						if RN.fieldPrices.permitFieldRent then
							if #RN.farmlandForLease > 0 then
								for j =  1,#RN.farmlandForLease do
									if RN.farmlandForLease[j] == farmlandId then
										farmland.price =  math.floor(RN.fieldPrices.rentPriceScale * RN.fieldPrices.pricePerHa * farmlandArea);
										RN.farmlandOwnerType[i] = "For rent";
									end;
								end;
							end;
						end;
]]--
						print(" ");
						if isOwned then
							print(" field id:   "..fieldId.." Area (Ha):"..fieldArea.." Crop: "..fruitName.." Is owned = true");
						else
							print(" field id:   "..fieldId.." Area (Ha):"..fieldArea.." Crop: "..fruitName.." Is owned = false");
						end;
					end;
					print("farmland id: "..farmlandId.." Area (Ha): "..farmlandArea.." Price: "..farmland.price.." Ownership: "..RN.farmlandOwnerType[i]);
				end;
			else
				print("g_fieldManager.farmlandIdFieldMapping do not exists")
			end;
			print("\n --- RealNumbersFieldPrices.lua updates every 10 min --- \n");
	end;

	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_y) then


			print("\n --- RealNumbersFieldPrices.lua : lAlt-ry is pressed --- \n");

			local mapName = g_currentMission.missionInfo.mapTitle;
			print("\n --- "..mapName.. " --- \n");

			print("Field size, Seed usage, Yield with 100% bonus, Value of crop, Value per hectare of crop,  Windrow Liters\n")
			print(" Field id      Area (ha)   Seed (L)  Max yield (L)   Value     Value/ha  Windrow (L) Crop")
			if g_fieldManager.farmlandIdFieldMapping ~= nil then
				for i, land in pairs(g_fieldManager.farmlandIdFieldMapping) do

					for k, field in pairs(land) do
						farmland = field.farmland;
						farmlandArea = farmland.areaInHa;
						farmlandId = farmland.id;
						isOwned = farmland.isOwned;
						fieldId = field.fieldId;
						fieldArea = field.fieldArea;
						fruitTypeIndex = field.fruitType;
						fruitType = g_fruitTypeManager:getFruitTypeByIndex(fruitTypeIndex);

						if fruitType ~= nil then
							fruitName = string.upper(fruitType.name);
							seedUsage = 10000 * fruitType.seedUsagePerSqm  * fieldArea;
							maxYield = 2 * 10000 * g_fruitTypeManager.nameToFruitType[fruitName].literPerSqm * fieldArea;
							pricePerLiter = fruitType.fillType.pricePerLiter;
							value = maxYield * pricePerLiter;
							valuePerHa = value / fieldArea;
							if fruitType.windrowLiterPerSqm ~= nil then
								windrowYield = 10000 * fruitType.windrowLiterPerSqm  * fieldArea;
--								print("windrowLiterPerSqm = "..fruitType.windrowLiterPerSqm.." Windrow yield = "..windrowYield);
							else
								windrowYield = 0;
							end;
						else
							fruitName = "Undefined";
							seedUsage = 0;
							maxYield  = 0;
							pricePerLiter = 0;
							value = 0;
							valuePerHa = 0;
							windrowYield = 0;
						end;
						if isOwned then
							myPrintMyFields(fieldId, fieldArea, seedUsage, maxYield, value, valuePerHa, windrowYield, fruitName, textWidth);
						end;
					end;
				end;
			else
				print("g_fieldManager.farmlandIdFieldMapping do not exists")
			end;
			print("\n --- RealNumbersFieldPrices.lua updates every 10 min --- \n");
	end;
end;

function RealNumbersFieldPrices:update(dt)
	local currentMonth = 1;
	local leasingMonthsLeft = 1;
	local leasingYearFraction = 1;
	local fruitName = "Undefined";
	local cropValue = 0;
	local minute = g_currentMission.environment.currentMinute;
	local runMinute = minute % 10; -- remainder
	if runMinute ~= 4 then RN.notRunYetRealNumbersFieldPrices = true; end;
	if runMinute == 4 or RN.upStartRealNumbersFieldPrices then
		if RN.notRunYetRealNumbersFieldPrices then
			if g_fieldManager.fields ~= nil then
				g_farmlandManager.pricePerHa = RN.fieldPrices.pricePerHa;
			end;

			currentMonth = (g_currentMission.environment.currentPeriod + 2) % 12;	 -- March is apparently month 1
			if currentMonth == 0 then currentMonth = 12; end;

			leasingMonthsLeft =  12 + RN.fieldLeaseTerminationMonth - currentMonth;
			leasingYearFraction = leasingMonthsLeft/12;		
			if g_fieldManager.farmlandIdFieldMapping ~= nil then

				for i, land in pairs(g_fieldManager.farmlandIdFieldMapping) do
					for k, field in pairs(land) do
						local farmland = field.farmland;
						local farmlandArea = farmland.areaInHa;
						local farmlandId = farmland.id;
						local isOwned = farmland.isOwned;
						local fieldId = field.fieldId;
						local fieldArea = field.fieldArea;
						local fruitTypeIndex = field.fruitType;
						local fruitType = g_fruitTypeManager:getFruitTypeByIndex(fruitTypeIndex);
						if fruitType ~= nil then
							fruitName = fruitType.name;					
						else
							fruitName = "Undefined";
						end;
						RN.farmlandOwnerType[i] = "For sale";
						farmland.price =  RN.fieldPrices.pricePerHa * farmlandArea;
						if RN.fieldPrices.permitFieldRent then
							if #RN.farmlandForLease > 0 then
								for j =  1,#RN.farmlandForLease do
									if RN.farmlandForLease[j] == farmlandId then
										if currentMonth == RN.fieldLeaseTerminationMonth then		-- terminate all field leases
											farmland.price = 0;										-- Set price to zero in lease-free month so no gain from trading
											farmland.isOwned = false;
											field.mapHotspot.textBold = false;
											field.mapHotspot.ownerFarmId = 0;						-- change owner to FarmId 0
											field.mapHotspot.color = {1, 1, 1, 1};					-- turn blue field numbers white
											g_farmlandManager.farmlandMapping[farmlandId] = 0;
										else
											farmland.price =  math.floor(leasingYearFraction * RN.fieldPrices.rentPriceScale * RN.fieldPrices.pricePerHa * farmlandArea);
											RN.farmlandOwnerType[i] = "For rent";
										end;
									end;
								end;
							end;
						end;
					end;
				end;
			end;
		end;
		RN.notRunYetRealNumbersFieldPrices = false;
		RN.upStartRealNumbersFieldPrices = false;
	end;
end;
function RealNumbersFieldPrices:draw()
end;
function RealNumbersFieldPrices:deleteMap()
end;
function RealNumbersFieldPrices:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersFieldPrices);







